<a id="top"></a>
<br />

<div align="center">
  <h1>django-ptpython</h1>
  <p align="center">
    PtPython as the Default Django Shell.
    <br />
    <br />
    <a href="https://github.com/reganto/django-ptpython/actions?query=workflow%3ALinters+event%3Apush+branch%3Amaster" target="_blank">
    <img src="https://github.com/reganto/django-ptpython/workflows/Linters/badge.svg?event=push&branch=master" alt="Test">
    </a>
    <a href="https://github.com/reganto/django-ptpython/issues"><img src="https://img.shields.io/github/issues/reganto/django-ptpython"></a> <a href="https://github.com/reganto/django-ptpython/blob/master/LICENSE.txt"><img src="https://img.shields.io/github/license/reganto/django-ptpython"></a>  <a href="https://badge.fury.io/py/django-ptpython"><img src="https://badge.fury.io/py/django-ptpython.svg" alt="PyPI version" height="18"></a> <a href="https://pepy.tech/project/django-ptpython"><img src="https://pepy.tech/badge/django-ptpython"/></a>
  </p>
</div>

<!-- Getting Started -->

## Getting Started

### Install the Package

Install it via pip:

```bash
pip install django-ptpython
```

### Install the App

Add `django-ptpython` to your `INSTALLED_APPS` setting:

```python
INSTALLED_APPS = [
    # ...
    "django_ptpython",
    # ...
]
```

<!-- USAGE EXAMPLES -->

## Usage

```bash
./manage.py shell
```

![screenshot](https://user-images.githubusercontent.com/29402115/164965563-5d2091ef-e880-49a3-bef9-f1fc49419e54.png)

<!-- LICENSE -->

## License

Distributed under the Apache License. See [LICENSE](https://github.com/reganto/django-ptpython/blob/master/LICENSE.txt) for more information.

<!-- CONTACT -->

## Contact

Email: tell.reganto[at]gmail[dot]com
